@@ -3,7 +3,7 @@ import subprocess
 import sys
 from pathlib import Path
 
-from first_steps import tutorial001 as mod
+from docs_src.first_steps import tutorial001 as mod
 
 
 def test_show_completion():
