@@ -7,7 +7,7 @@ import shellingham
 import typer
 from typer.testing import CliRunner
 
-from first_steps import tutorial001 as mod
+from docs_src.first_steps import tutorial001 as mod
 
 runner = CliRunner()
 app = typer.Typer()
