@@ -3,7 +3,7 @@ import subprocess
 import typer
 from typer.testing import CliRunner
 
-from multiple_values.options_with_multiple_values import tutorial001 as mod
+from docs_src.multiple_values.options_with_multiple_values import tutorial001 as mod
 
 runner = CliRunner()
 app = typer.Typer()
